@@ -245,6 +245,13 @@ LINPHONE_PUBLIC LinphoneCallCbs * linphone_factory_create_call_cbs(const Linphon
  */
 LINPHONE_PUBLIC LinphoneConferenceCbs * linphone_factory_create_conference_cbs(const LinphoneFactory *factory);
 
+/**
+ * Create a #LinphoneParticipantDeviceCbs object that holds callbacks for events happening on a participant device.
+ * @param[in] factory #LinphoneFactory singletion object @notnil
+ * @return A new #LinphoneParticipantDeviceCbs object @notnil
+ */
+LINPHONE_PUBLIC LinphoneParticipantDeviceCbs * linphone_factory_create_participant_device_cbs(const LinphoneFactory *factory);
+
 /**
  * Create a LinphoneChatRoomCbs object that holds callbacks for events happening on a chat room.
  * @param factory #LinphoneFactory singletion object @notnil
@@ -298,10 +305,18 @@ LINPHONE_PUBLIC LinphoneVideoDefinition * linphone_factory_create_video_definiti
  */
 LINPHONE_PUBLIC const bctbx_list_t * linphone_factory_get_supported_video_definitions(const LinphoneFactory *factory);
 
+/**
+ * Get the recommended list of standard video definitions.
+ * This list is suitable for a widest set of hardware for all video codec implementations, and thus excludes some very high definition formats that are unlikely to work unless specific hardware or codecs are used.
+ * @param factory #LinphoneFactory singleton object @notnil
+ * @return A list of video definitions. \bctbx_list{LinphoneVideoDefinition} @maybenil
+ */
+LINPHONE_PUBLIC const bctbx_list_t * linphone_factory_get_recommended_video_definitions(const LinphoneFactory *factory);
+
 /**
  * Get the top directory where the resources are located.
  * @param factory #LinphoneFactory object @notnil
- * @return The path to the top directory where the resources are located @notnil
+ * @return The path to the top directory where the resources are located @maybenil
  */
 LINPHONE_PUBLIC const char * linphone_factory_get_top_resources_dir(const LinphoneFactory *factory);
 
@@ -309,63 +324,63 @@ LINPHONE_PUBLIC const char * linphone_factory_get_top_resources_dir(const Linpho
  * Set the top directory where the resources are located.
  * If you only define this top directory, the other resources directory will automatically be derived form this one.
  * @param factory #LinphoneFactory object @notnil
- * @param path The path to the top directory where the resources are located @notnil
+ * @param path The path to the top directory where the resources are located @maybenil
  */
 LINPHONE_PUBLIC void linphone_factory_set_top_resources_dir(LinphoneFactory *factory, const char *path);
 
 /**
  * Get the directory where the data resources are located.
  * @param factory #LinphoneFactory object @notnil
- * @return The path to the directory where the data resources are located @notnil
+ * @return The path to the directory where the data resources are located @maybenil
  */
 LINPHONE_PUBLIC const char * linphone_factory_get_data_resources_dir(LinphoneFactory *factory);
 
 /**
  * Set the directory where the data resources are located.
  * @param factory #LinphoneFactory object @notnil
- * @param path The path where the data resources are located @notnil
+ * @param path The path where the data resources are located @maybenil
  */
 LINPHONE_PUBLIC void linphone_factory_set_data_resources_dir(LinphoneFactory *factory, const char *path);
 
 /**
  * Get the directory where the sound resources are located.
  * @param factory #LinphoneFactory object @notnil
- * @return The path to the directory where the sound resources are located @notnil
+ * @return The path to the directory where the sound resources are located @maybenil
  */
 LINPHONE_PUBLIC const char * linphone_factory_get_sound_resources_dir(LinphoneFactory *factory);
 
 /**
  * Set the directory where the sound resources are located.
  * @param factory #LinphoneFactory object @notnil
- * @param path The path where the sound resources are located @notnil
+ * @param path The path where the sound resources are located @maybenil
  */
 LINPHONE_PUBLIC void linphone_factory_set_sound_resources_dir(LinphoneFactory *factory, const char *path);
 
 /**
  * Get the directory where the ring resources are located.
  * @param factory #LinphoneFactory object @notnil
- * @return The path to the directory where the ring resources are located @notnil
+ * @return The path to the directory where the ring resources are located @maybenil
  */
 LINPHONE_PUBLIC const char * linphone_factory_get_ring_resources_dir(LinphoneFactory *factory);
 
 /**
  * Set the directory where the ring resources are located.
  * @param factory #LinphoneFactory object @notnil
- * @param path The path where the ring resources are located @notnil
+ * @param path The path where the ring resources are located @maybenil
  */
 LINPHONE_PUBLIC void linphone_factory_set_ring_resources_dir(LinphoneFactory *factory, const char *path);
 
 /**
  * Get the directory where the image resources are located.
  * @param factory #LinphoneFactory object @notnil
- * @return The path to the directory where the image resources are located @notnil
+ * @return The path to the directory where the image resources are located @maybenil
  */
 LINPHONE_PUBLIC const char * linphone_factory_get_image_resources_dir(LinphoneFactory *factory);
 
 /**
  * Set the directory where the image resources are located.
  * @param factory #LinphoneFactory object @notnil
- * @param path The path where the image resources are located @notnil
+ * @param path The path where the image resources are located @maybenil
  */
 LINPHONE_PUBLIC void linphone_factory_set_image_resources_dir(LinphoneFactory *factory, const char *path);
 
@@ -383,6 +398,81 @@ LINPHONE_PUBLIC const char * linphone_factory_get_msplugins_dir(LinphoneFactory
  */
 LINPHONE_PUBLIC void linphone_factory_set_msplugins_dir(LinphoneFactory *factory, const char *path);
 
+/**
+ * Get the config path
+ * @param factory the #LinphoneFactory @notnil
+ * @param context used to compute path. Can be NULL. JavaPlatformHelper on Android and char *appGroupId on iOS with shared core. @maybenil
+ * @return The config path @maybenil
+ * @ingroup misc
+**/
+LINPHONE_PUBLIC const char *linphone_factory_get_config_dir(LinphoneFactory *factory, void *context);
+
+/**
+ * Test if config dir has been set.
+ * @param factory the #LinphoneFactory @notnil
+ * @return TRUE if config dir has been set.
+ * @ingroup misc
+**/
+LINPHONE_PUBLIC bool_t linphone_factory_is_config_dir_set(const LinphoneFactory *factory);
+
+/**
+ * Set the directory where the configurations are located.
+ * If the path is empty (default value), the path will be computed when calling linphone_factory_get_config_dir()
+ * @param factory #LinphoneFactory object @notnil
+ * @param path The path to the directory where the configurations are located @maybenil
+ */
+LINPHONE_PUBLIC void linphone_factory_set_config_dir(LinphoneFactory *factory, const char *path);
+
+/**
+ * Get the data path
+ * @param factory the #LinphoneFactory @notnil
+ * @param context used to compute path. Can be NULL. JavaPlatformHelper on Android and char *appGroupId on iOS with shared core. @maybenil
+ * @return The data path @maybenil
+ * @ingroup misc
+**/
+LINPHONE_PUBLIC const char *linphone_factory_get_data_dir(LinphoneFactory *factory, void *context);
+
+/**
+ * Test if data dir has been set.
+ * @param factory the #LinphoneFactory @notnil
+ * @return TRUE if data dir has been set.
+ * @ingroup misc
+**/
+LINPHONE_PUBLIC bool_t linphone_factory_is_data_dir_set(const LinphoneFactory *factory);
+
+/**
+ * Set the directory where the application local data are located.
+ * If the path is empty (default value), the path will be computed when calling linphone_factory_get_data_dir()
+ * @param factory #LinphoneFactory object @notnil
+ * @param path The path to the directory where the application local data are located @maybenil
+ */
+LINPHONE_PUBLIC void linphone_factory_set_data_dir(LinphoneFactory *factory, const char *path);
+
+/**
+ * Get the download path
+ * @param factory the #LinphoneFactory @notnil
+ * @param context used to compute path. Can be NULL. JavaPlatformHelper on Android and char *appGroupId on iOS with shared core. @maybenil
+ * @return The download path @maybenil
+ * @ingroup misc
+**/
+LINPHONE_PUBLIC const char *linphone_factory_get_download_dir(LinphoneFactory *factory, void *context);
+
+/**
+ * Test if download dir has been set.
+ * @param factory the #LinphoneFactory @notnil
+ * @return TRUE if download dir has been set.
+ * @ingroup misc
+**/
+LINPHONE_PUBLIC bool_t linphone_factory_is_download_dir_set(const LinphoneFactory *factory);
+
+/**
+ * Set the directory where downloads are located.
+ * If the path is empty (default value), the path will be computed when calling linphone_factory_get_download_dir()
+ * @param factory #LinphoneFactory object @notnil
+ * @param path The path to the directory where downloads are located @maybenil
+ */
+LINPHONE_PUBLIC void linphone_factory_set_download_dir(LinphoneFactory *factory, const char *path);
+
 /**
  * Creates an object LinphoneErrorInfo.
  * @param factory #LinphoneFactory object @notnil
@@ -581,31 +671,20 @@ LINPHONE_PUBLIC bool_t linphone_factory_is_database_storage_available(LinphoneFa
 LINPHONE_PUBLIC bool_t linphone_factory_is_imdn_available(LinphoneFactory *factory);
 
 /**
- * Get the config path
+ * Creates an object #LinphoneConferenceInfo
  * @param factory the #LinphoneFactory @notnil
- * @param context used to compute path. Can be NULL. JavaPlatformHelper on Android and char *appGroupId on iOS with shared core. @maybenil
- * @return The config path @notnil
- * @ingroup misc
-**/
-LINPHONE_PUBLIC const char *linphone_factory_get_config_dir(LinphoneFactory *factory, void *context);
+ * @return a #LinphoneConferenceInfo @notnil
+ */
+LINPHONE_PUBLIC LinphoneConferenceInfo *linphone_factory_create_conference_info(LinphoneFactory *factory);
 
 /**
- * Get the data path
+ * Creates an object #LinphoneConferenceInfo from an Icalendar #LinphoneContent
  * @param factory the #LinphoneFactory @notnil
- * @param context used to compute path. Can be NULL. JavaPlatformHelper on Android and char *appGroupId on iOS with shared core. @maybenil
- * @return The data path @notnil
- * @ingroup misc
-**/
-LINPHONE_PUBLIC const char *linphone_factory_get_data_dir(LinphoneFactory *factory, void *context);
+ * @param content the Icalendar #LinphoneContent @notnil
+ * @return a #LinphoneConferenceInfo created from an Icalendar #LinphoneContent @maybenil
+ */
+LINPHONE_PUBLIC LinphoneConferenceInfo *linphone_factory_create_conference_info_from_icalendar_content(LinphoneFactory *factory, LinphoneContent *content);
 
-/**
- * Get the download path
- * @param factory the #LinphoneFactory @notnil
- * @param context used to compute path. Can be NULL. JavaPlatformHelper on Android and char *appGroupId on iOS with shared core. @maybenil
- * @return The download path @notnil
- * @ingroup misc
-**/
-LINPHONE_PUBLIC const char *linphone_factory_get_download_dir(LinphoneFactory *factory, void *context);
 
 /************ */
 /* DEPRECATED */
@@ -728,6 +807,28 @@ LINPHONE_DEPRECATED LINPHONE_PUBLIC LinphoneCore *linphone_factory_create_core_w
  * @param[in]	secretSize		size of the secret
  */
 LINPHONE_PUBLIC void linphone_factory_set_vfs_encryption(LinphoneFactory *factory, const uint16_t encryptionModule, const uint8_t *secret, const size_t secretSize);
+
+
+/**
+ * Create a #LinphoneDigestAuthenticationPolicy object.
+ * 
+ * The #LinphoneDigestAuthenticationPolicy object which is used to configure a policy for digest authentication,
+ * such as allowing MD5 or mode without qop=auth.
+ * @param factory The #LinphoneFactory @notnil
+ * @return a new #LinphoneDigestAuthenticationPolicy . @notnil
+ */
+LINPHONE_PUBLIC LinphoneDigestAuthenticationPolicy *linphone_factory_create_digest_authentication_policy(const LinphoneFactory *factory);
+
+/**
+ * Creates a new #LinphoneFriendPhoneNumber objects.
+ * @param factory The #LinphoneFactory @notnil
+ * @param phone_number The phone number. @notnil
+ * @param label the type of phone number, for example "home", "cell", etc. Use NULL or empty for no label. @maybenil
+ * @return The newly created #LinphoneFriendPhoneNumber object. @notnil
+ */
+LINPHONE_PUBLIC LinphoneFriendPhoneNumber* linphone_factory_create_friend_phone_number(const LinphoneFactory *factory, const char *phone_number, const char *label);
+
+
 /**
  * @}
  */
