@@ -158,6 +158,13 @@ typedef struct _LinphoneConferenceParams LinphoneConferenceParams;
  */
 typedef struct _LinphoneConferenceCbs LinphoneConferenceCbs;
 
+/**
+ * @brief Object defining all informations of a conference
+ *
+ * @ingroup conference
+ */
+typedef struct _LinphoneConferenceInfo LinphoneConferenceInfo;
+
 // -----------------------------------------------------------------------------
 // Participants.
 // -----------------------------------------------------------------------------
@@ -182,6 +189,15 @@ typedef struct _LinphoneParticipant LinphoneParticipant;
  */
 typedef struct _LinphoneParticipantDevice LinphoneParticipantDevice;
 
+/**
+ * @brief An object to handle the callbacks for the handling a #LinphoneParticipantDevice objects.
+ *
+ * Use linphone_factory_create_participant_device_cbs() to create an instance.
+ * Then pass the object to a #LinphoneParticipantDevice instance through linphone_participant_device_add_callbacks().
+ * @ingroup conference
+ */
+typedef struct _LinphoneParticipantDeviceCbs LinphoneParticipantDeviceCbs;
+
 /**
  * @brief This object represents the delivery/display state of a given chat message for a given participant.
  * 
@@ -206,9 +222,11 @@ typedef struct _LinphoneParticipantDeviceIdentity LinphoneParticipantDeviceIdent
 /**
  * @brief This object represents a call issued or received by the #LinphoneCore.
  * 
- * You may have multiple calls at the same time, but only one will be 
- * in #LinphoneCallStateStreamsRunning at any time unless they are merged into a #LinphoneConference,
- * others will be paused.
+ * Linphone only allows at most one active call at any given time and it will be
+ * in #LinphoneCallStateStreamsRunning. However, if the core is locally hosting a #LinphoneConference,
+ * you may have some or all the calls in the conference in #LinphoneCallStateStreamsRunning
+ * as well as an additional active call outside of the conference in #LinphoneCallStateStreamsRunning
+ * if the local participant of the #LinphoneConference is not part of it.
  * 
  * You can get the #LinphoneCallState of the call using linphone_call_get_state(),
  * it's current #LinphoneCallParams with linphone_call_get_current_params() and 
@@ -248,6 +266,20 @@ typedef struct _LinphoneCallCbs LinphoneCallCbs;
 **/
 typedef struct _LinphoneCallParams LinphoneCallParams;
 
+/**
+ * @brief Object used to record the audio or video of a call.
+ * 
+ * @ingroup call_control
+**/
+typedef struct _LinphoneRecorder LinphoneRecorder;
+
+/**
+ * @brief Object containing various parameters of a #LinphoneRecorder.
+ * 
+ * @ingroup call_control
+**/
+typedef struct _LinphoneRecorderParams LinphoneRecorderParams;
+
 /**
  * @brief Object used to keep track of all calls initiated, received or missed.
  * 
@@ -371,6 +403,71 @@ typedef struct _LinphoneChatRoomCbs LinphoneChatRoomCbs;
  */
 typedef struct _LinphoneEventLog LinphoneEventLog;
 
+// -----------------------------------------------------------------------------
+// LDAP.
+// -----------------------------------------------------------------------------
+
+/**
+ * Object that represents a Linphone Ldap.
+ * Use a #LinphoneLdapParams object to configure it.
+ * @ingroup ldap
+ */
+typedef struct _LinphoneLdap LinphoneLdap;
+
+/**
+ * Object that is used to set the different parameters of a #LinphoneLdap.
+ * @ingroup ldap
+ */
+typedef struct _LinphoneLdapParams LinphoneLdapParams;
+
+/**
+ * @brief Enum Debug verbosity for OpenLdap
+ * @ingroup ldap
+**/
+typedef enum _LinphoneLdapDebugLevel {
+	LinphoneLdapDebugLevelOff = 0, /**< Set OpenLdap verbosity to none */
+	LinphoneLdapDebugLevelVerbose = 1, /**< Set OpenLdap verbosity to debug level */
+} LinphoneLdapDebugLevel;
+
+/**
+ * @brief Enum describing how the authentification will be made.
+ * @ingroup ldap
+**/
+typedef enum _LinphoneLdapAuthMethod {
+	LinphoneLdapAuthMethodAnonymous = 0, /**< Connection without passwords */
+	LinphoneLdapAuthMethodSimple = 1, /**< Connection with username/password */
+} LinphoneLdapAuthMethod;
+
+/**
+ * @brief Enum describing server certificates verification modes.
+ * @ingroup ldap
+**/
+typedef enum _LinphoneLdapCertVerificationMode {
+	LinphoneLdapCertVerificationDefault = -1, /**< Use default value defined on core */
+	LinphoneLdapCertVerificationDisabled = 0, /**< Verification is disabled*/
+	LinphoneLdapCertVerificationEnabled = 1 /**< Verification is enabled*/
+} LinphoneLdapCertVerificationMode;
+
+/**
+ * @brief Enum describing errors in LDAP parameters.
+ * @ingroup ldap
+**/
+typedef enum _LinphoneLdapCheck{
+	LinphoneLdapCheckOk = 0,						/**< No error */
+
+	LinphoneLdapCheckServerEmpty = 1,				/**< Server field is empty */
+	LinphoneLdapCheckServerNotUrl = 2,				/**< The server is not an url*/
+	LinphoneLdapCheckServerNoScheme = 4,			/**< The server doesn't contain a scheme*/
+	LinphoneLdapCheckServerNotLdap = 8,				/**< The server is not a LDAP scheme */
+	LinphoneLdapCheckServerLdaps = 16,				/**< LDAP over SSL is non-standardized and deprecated: ldaps has been specified */
+
+	LinphoneLdapCheckBaseObjectEmpty = 32,			/**< Base Object has been specified */
+
+	LinphoneLdapCheckMissingFields = 64,			/**< Some required fields are missing*/
+
+}LinphoneLdapCheck;
+
+
 // -----------------------------------------------------------------------------
 // Misc.
 // -----------------------------------------------------------------------------
@@ -436,6 +533,27 @@ typedef struct _LinphoneMagicSearchCbs LinphoneMagicSearchCbs;
  */
 typedef struct _LinphoneSearchResult LinphoneSearchResult;
 
+// -----------------------------------------------------------------------------
+// Digest authentication policy.
+// -----------------------------------------------------------------------------
+
+/**
+ * @brief The LinphoneDigestAuthenticationPolicy holds parameters relative to digest authentication procedures.
+ * @ingroup misc
+ */
+typedef struct _LinphoneDigestAuthenticationPolicy LinphoneDigestAuthenticationPolicy;
+
+
+// -----------------------------------------------------------------------------
+// Friend.
+// -----------------------------------------------------------------------------
+
+/**
+ * Object that represents a #LinphoneFriend's phone number.
+ * @ingroup buddy_list
+ */
+typedef struct _LinphoneFriendPhoneNumber LinphoneFriendPhoneNumber;
+
 #ifdef __cplusplus
 	}
 #endif // ifdef __cplusplus
