@@ -243,6 +243,15 @@ typedef enum _LinphoneCallDir {
 **/
 typedef struct _LinphoneCallStats LinphoneCallStats;
 
+/**
+ * @ingroup call_misc
+ */
+typedef enum _LinphoneSupportLevel {
+	LinphoneSupportLevelNoSupport = 0, /**< No support for the feature */
+	LinphoneSupportLevelOptional = 1, /**< Optional support for the feature */
+	LinphoneSupportLevelMandatory = 2, /**< Mandatory support for the feature */
+} LinphoneSupportLevel;
+
 /**
  * @brief Enum representing the status of a call.
  * @ingroup call_logs
@@ -257,6 +266,26 @@ typedef enum _LinphoneCallStatus {
 	LinphoneCallDeclinedElsewhere = 6 /**<The call was declined on another device*/
 } LinphoneCallStatus;
 
+/**
+ * @brief Enum representing the file format of a recording.
+ * @ingroup call_control
+**/
+typedef enum _LinphoneRecorderFileFormat {
+	LinphoneRecorderFileFormatUnknown,
+	LinphoneRecorderFileFormatWav,
+	LinphoneRecorderFileFormatMkv
+} LinphoneRecorderFileFormat;
+
+/**
+ * @brief Enum representing the state of a recording.
+ * @ingroup call_control
+**/
+typedef enum _LinphoneRecorderState {
+	LinphoneRecorderClosed, /**< No file is opened for recording. */
+	LinphoneRecorderPaused, /**< The recorder is paused. */
+	LinphoneRecorderRunning /**< The recorder is running. */
+} LinphoneRecorderState;
+
 // -----------------------------------------------------------------------------
 // Friends.
 // -----------------------------------------------------------------------------
@@ -294,6 +323,15 @@ typedef enum _LinphoneFriendCapability {
 **/
 typedef struct _LinphoneFriendList LinphoneFriendList;
 
+/**
+ * @brief The types of FriendList
+ * @ingroup buddy_list
+ */
+typedef enum _LinphoneFriendListType {
+	LinphoneFriendListTypeCardDAV = 0,
+	LinphoneFriendListTypeVCard4 = 1
+} LinphoneFriendListType;
+
 /**
  * @brief An object to handle the callbacks for #LinphoneFriend synchronization.
  * @ingroup buddy_list
@@ -473,6 +511,16 @@ typedef struct _LinphoneVideoActivationPolicy LinphoneVideoActivationPolicy;
  */
 typedef struct _LinphoneVideoDefinition LinphoneVideoDefinition;
 
+/**
+ * @brief Describes conference invitations possible errors.
+ *
+ * It is notified via the conference_info_on_participant_error() callback in #LinphoneCoreCbs.
+ * @ingroup misc
+**/
+typedef enum _LinphoneConferenceInfoError {
+	LinphoneConferenceInfoChatRoomError = 0, /**< Could not create or retrieve chat room */
+} LinphoneConferenceInfoError;
+
 // -----------------------------------------------------------------------------
 // Other.
 // -----------------------------------------------------------------------------
@@ -1005,7 +1053,8 @@ typedef enum _LinphoneReason{
 	LinphoneReasonBadGateway = 19, /**< Bad gateway */
 	LinphoneReasonSessionIntervalTooSmall = 20, /**< The received request contains a Session-Expires header field with a duration below the minimum timer */
 	LinphoneReasonServerTimeout = 21, /**< Server timeout */
-	LinphoneReasonUnknown = 22 /**< Unknown reason */
+	LinphoneReasonUnknown = 22, /**< Unknown reason */
+	LinphoneReasonTransferred= 23 /**< The call has been transferred */
 } LinphoneReason;
 
 #define LinphoneReasonBadCredentials LinphoneReasonForbidden
@@ -1266,4 +1315,28 @@ typedef int LinphoneStatus;
 **/
 typedef struct _LinphoneHeaders LinphoneHeaders;
 
+/**
+* @brief Enum describing the search categories for Magic Search
+* @ingroup buddy_list
+**/
+typedef enum _LinphoneMagicSearchSource {
+	LinphoneMagicSearchSourceNone = 0, /**< no Source specified. If requested in search, the list should be empty */
+	LinphoneMagicSearchSourceFriends = 1 << 0, /**< Search in friends only */
+	LinphoneMagicSearchSourceCallLogs = 1 << 1, /**< Search in Call Logs */
+	LinphoneMagicSearchSourceLdapServers = 1 << 2, /**< Search in LDAP servers */
+	LinphoneMagicSearchSourceChatRooms = 1 << 3, /**< Search in Chat rooms participants */
+	LinphoneMagicSearchSourceRequest = 1 << 4, /**< Search from request : it is usually an address built from the request */
+	LinphoneMagicSearchSourceAll = -1 /**< Search in all sources */
+} LinphoneMagicSearchSource;
+
+/**
+* @brief Enum describing how to merge #LinphoneSearchResult from #LinphoneMagicSearch
+* @ingroup buddy_list
+**/
+typedef enum _LinphoneMagicSearchAggregation {
+	LinphoneMagicSearchAggregationNone = 0, /**< No aggregation is done, you can have multiple SearchResult with the same Friend */
+	LinphoneMagicSearchAggregationFriend = 1 /**< Aggregation is done by friend, you will have at most a SearchResult per Friend */
+} LinphoneMagicSearchAggregation;
+
+
 #endif /* LINPHONE_TYPES_H_ */
